/*
    Introduction to OOP with Java (5th Ed), McGraw-Hill

    Wu/Otani

    Chapter 9 Sample Development: Word Concordance

    File: Step2/Ch9WordConcordanceMain.java
*/

import java.io.*;
import java.util.*;

/**
 *   class Ch9WordConcordanceMain (Step 2)
 *
 *   The instantialble main class for Step 2.
 *
 */
class Ch9WordConcordanceMain  {

//----------------------------------
//    Data Members
//----------------------------------
    private static enum Response {YES, NO}
    
    /** File manager for opening and saving a file */
    private FileManager fileManager;

    /** Word concordance builder */
    private Ch9WordConcordance builder;
    
    /** Scanner for getting input*/
    private Scanner scanner;


//----------------------------------
//      Sample main method
//----------------------------------
    public static void main(String[] args) {
        Ch9WordConcordanceMain main = new Ch9WordConcordanceMain();
        main.start();
    }

//----------------------------------
//    Constructors
//----------------------------------

    /**
     * Default constructor
     */
    public Ch9WordConcordanceMain() {

        fileManager = new FileManager( );
        builder     = new Ch9WordConcordance( );
        
        scanner     = new Scanner(System.in);
    }

//----------------------------------
//    Private Methods
//
//          void start(     )
//
//----------------------------------
    /**
     * Build the word concordance.
     */
    private String build(String document) {

        String concordance;

        concordance = builder.build(document);

        return concordance;
    }

    /**
     * Input text data from a file
     */
    private String inputFile( ) {
        String doc = "";

        try {
            doc = fileManager.openFile( );

        } catch (FileNotFoundException e) {
            System.out.println("File not found in the directory it is expected.");

        } catch (IOException e) {
            System.out.println("Error in opening file: " + e.getMessage());
        }

        System.out.println("Input Document:\n" + doc); //TEMP

        return doc;
    }


    /**
     * Save the word list to a file.
     */
    private void saveFile(String list) {

        try {
            fileManager.saveFile(list);
        } catch (IOException e) {
            System.out.println("Error in saving file: " + e.getMessage());
        }
    }
    
    
    /**
     * Top level control
     */
    private void start( ) {
        
        Response userReply;
        
        String document, wordList;

        while (true) {

            userReply = prompt("Run the program?");
            
            if (userReply == Response.NO) {
                break;
            }
            
            document = inputFile();

            wordList = build(document);

            saveFile(wordList);
        }

        System.out.println("Thank you for using the program. Good-Bye");
    }
    
    private Response prompt(String question) {

        String input;

        Response response = Response.NO;

        System.out.print(question + " (Yes - y; No - n): ");

        input = scanner.next();

        if (input.equals("Y") || input.equals("y")) {
            response = Response.YES;
        }

        return response;
    }
}